@@ -114,6 +114,7 @@ remove_hide_timeout (GsdMediaKeysWindow *window)
         if (window->priv->fade_timeout_id != 0) {
                 g_source_remove (window->priv->fade_timeout_id);
                 window->priv->fade_timeout_id = 0;
+                window->priv->fade_out_alpha = 1.0;
         }
 }
 
@@ -826,6 +827,32 @@ gsd_media_keys_window_real_hide (GtkWidget *widget)
         remove_hide_timeout (window);
 }
 
+static void
+gsd_media_keys_window_real_realize (GtkWidget *widget)
+{
+        GdkBitmap *mask;
+        cairo_t *cr;
+
+        if (GTK_WIDGET_CLASS (gsd_media_keys_window_parent_class)->realize) {
+                GTK_WIDGET_CLASS (gsd_media_keys_window_parent_class)->realize (widget);
+        }
+
+        mask = gdk_pixmap_new (widget->window,
+                               widget->allocation.width,
+                               widget->allocation.height,
+                               1);
+        cr = gdk_cairo_create (mask);
+
+        cairo_set_source_rgba (cr, 1., 1., 1., 0.);
+        cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+        cairo_paint (cr);
+
+        /* make the whole window ignore events */
+        gdk_window_input_shape_combine_mask (widget->window, mask, 0, 0);
+        g_object_unref (mask);
+        cairo_destroy (cr);
+}
+
 static void
 gsd_media_keys_window_class_init (GsdMediaKeysWindowClass *klass)
 {
@@ -833,6 +860,7 @@ gsd_media_keys_window_class_init (GsdMediaKeysWindowClass *klass)
 
         widget_class->show = gsd_media_keys_window_real_show;
         widget_class->hide = gsd_media_keys_window_real_hide;
+        widget_class->realize = gsd_media_keys_window_real_realize;
 
         g_type_class_add_private (klass, sizeof (GsdMediaKeysWindowPrivate));
 }
@@ -915,6 +943,7 @@ gsd_media_keys_window_new (void)
 
         object = g_object_new (GSD_TYPE_MEDIA_KEYS_WINDOW,
                                "type", GTK_WINDOW_POPUP,
+                               "type-hint", GDK_WINDOW_TYPE_HINT_NOTIFICATION,
                                "skip-taskbar-hint", TRUE,
                                "skip-pager-hint", TRUE,
                                "focus-on-map", FALSE,
